@@ -56,6 +56,19 @@ loaPlot <- function (x, data = NULL, panel = panel.loaPlot, ...,
     ##groups <- eval(substitute(groups), data, environment(x))
     #env <- environment(x)
 
+######################
+#test for matrix input
+######################
+
+
+    if(is.matrix(x)){
+        extra.args <- do.call(matrixHandler, listUpdate(list(x=x, data=data), extra.args))
+        x <- extra.args$x
+        data <- extra.args$data
+        extra.args <- extra.args[!names(extra.args) %in% c("x", "data")]
+
+    }
+
     #check for any panel defaults
     loa.settings <- loaHandler(panel)
 
@@ -114,7 +127,8 @@ loaPlot <- function (x, data = NULL, panel = panel.loaPlot, ...,
 ##################
 
 #    if("col.regions" %in% names(extra.args))
-        extra.args$col.regions <- do.call(colRegionsHandler, extra.args)
+        extra.args$col.regions <- do.call(colRegionsHandler, extra.args[!names(extra.args) %in% c("alpha","alpha.regions")])
+
 
 #if needed because col expanded to col.regions
 
@@ -412,7 +426,8 @@ panel.loaPlot <- function(..., loa.settings = FALSE){
     }
 
     if(isGood4LOA(extra.args$grid))
-        panel.loaGrid(panel.scales = extra.args$panel.scales, grid = extra.args$grid) 
+        panel.loaGrid(panel.scales = extra.args$panel.scales, grid = extra.args$grid, 
+                      xlim = extra.args$xlim, ylim = extra.args$ylim) 
 
     extra.args$col <- do.call(colHandler, extra.args)
     extra.args$cex <- do.call(cexHandler, extra.args)
@@ -466,6 +481,7 @@ panel.loaGrid <- function(grid.x = NULL, grid.y = NULL,
     x.par <- getPlotArgs("axis.line", local.resets = panel.scales, 
         user.resets = temp, elements = "x", defaults.only = FALSE)
     x.par$col.line <- x.par$col
+    x.par$x <- xlim
     do.call(panel.grid, x.par)
 
     temp <- listUpdate(grid, grid.y)
@@ -475,6 +491,7 @@ panel.loaGrid <- function(grid.x = NULL, grid.y = NULL,
     y.par <- getPlotArgs("axis.line", local.resets = panel.scales, 
         user.resets = temp, elements = "y", defaults.only = FALSE)
     y.par$col.line <- y.par$col
+    y.par$y <- ylim
     do.call(panel.grid, y.par)
 
 }
